@@ -16,6 +16,7 @@ flag_definitions = {
     # hole at bit 8
     # hole at bit 9. FIXME: Where is NO-HT40 defined?
     'NO-HT40':		1<<10,
+    'AUTO-BW':		1<<11,
 }
 
 dfs_regions = {
@@ -144,7 +145,10 @@ class DBParser(object):
     def _parse_band_def(self, bname, banddef, dupwarn=True):
         try:
             freqs, bw = banddef.split('@')
-            bw = float(bw)
+            if bw == "AUTO":
+                bw = 0.0
+            else:
+                bw = float(bw)
         except ValueError:
             bw = 20.0
 
